@@ -3,14 +3,12 @@ import logging
 import threading
 import typing as tp
 
-from .decorators import wraps
-
-ExcType = tp.Type[Exception]
-T = tp.TypeVar('T')
+from .decorators.decorators import wraps
+from .typing import ExceptionClassType, T, NoArgCallable
 
 
-def silence_excs(*exc_types: ExcType, returns=None,
-                 returns_factory: tp.Optional[tp.Callable[[], tp.Any]] = None):
+def silence_excs(*exc_types: ExceptionClassType, returns=None,
+                 returns_factory: tp.Optional[NoArgCallable[tp.Any]] = None):
     """
     Silence given exception types.
 
@@ -68,7 +66,8 @@ class log_exceptions:
                  severity: int = logging.ERROR,
                  format_string: str = '{e}',
                  locals_: tp.Optional[tp.Dict] = None,
-                 exc_types: tp.Union[ExcType, tp.Sequence[ExcType]] = Exception,
+                 exc_types: tp.Union[
+                     ExceptionClassType, tp.Sequence[ExceptionClassType]] = Exception,
                  swallow_exception: bool = False):
         self.logger = logger
         self.swallow_exception = swallow_exception
@@ -105,6 +104,7 @@ class log_exceptions:
         if inspect.isgeneratorfunction(fun):
             @wraps(fun)
             def inner(*args, **kwargs):
+                # noinspection PyBroadException
                 try:
                     yield from fun(*args, **kwargs)
                 except Exception as e:
@@ -117,6 +117,7 @@ class log_exceptions:
         else:
             @wraps(fun)
             def inner(*args, **kwargs):
+                # noinspection PyBroadException
                 try:
                     return fun(*args, **kwargs)
                 except Exception as e:
@@ -124,6 +125,7 @@ class log_exceptions:
                         raise
                     elif not self.swallow_exception:
                         raise
+
             return inner
 
 
@@ -160,10 +162,10 @@ class rethrow_as:
     __slots__ = ('mapping', 'exception_preprocessor', 'returns', '__exception_remapped',
                  'returns_factory')
 
-    def __init__(self, *pairs: tp.Union[ExcType, tp.Tuple[ExcType, ExcType]],
+    def __init__(self, *pairs: tp.Union[ExceptionClassType, tp.Tuple[ExceptionClassType, ...]],
                  exception_preprocessor: tp.Optional[tp.Callable[[Exception], str]] = repr,
                  returns=None,
-                 returns_factory: tp.Optional[tp.Callable[[], tp.Any]] = None):
+                 returns_factory: tp.Optional[NoArgCallable[tp.Any]] = None):
         try:
             a, b = pairs  # throws ValueError
             op = issubclass(b, BaseException)  # throws TypeError
@@ -219,8 +221,8 @@ class rethrow_as:
                         raise to(self.exception_preprocessor(exc_val))
 
 
-def raises_exception(exc_class: tp.Union[ExcType, tp.Tuple[ExcType, ...]],
-                     clb: tp.Callable[[], None]) -> bool:
+def raises_exception(exc_class: tp.Union[ExceptionClassType, tp.Tuple[ExceptionClassType, ...]],
+                     clb: NoArgCallable[None]) -> bool:
     """
     Does the callable raise a given exception?
     """
@@ -232,8 +234,8 @@ def raises_exception(exc_class: tp.Union[ExcType, tp.Tuple[ExcType, ...]],
         return False
 
 
-def catch_exception(exc_class: tp.Union[ExcType, tp.Tuple[ExcType, ...]],
-                    clb: tp.Callable[[], tp.Optional[T]],
+def catch_exception(exc_class: tp.Union[ExceptionClassType, tp.Tuple[ExceptionClassType, ...]],
+                    clb: NoArgCallable[tp.Optional[T]],
                     return_instead: tp.Optional[T] = None,
                     return_value_on_no_exception: bool = False) -> tp.Union[Exception, T]:
     """
