@@ -1,20 +1,37 @@
 from .dictionaries import DictObject, apply_dict_object, DictionaryView, TwoWayDictionary, \
     DirtyDict, KeyAwareDefaultDict, ExpiringEntryDict, SelfCleaningDefaultDict, \
-    CacheDict, ExclusiveWritebackCache
+    CacheDict, ExclusiveWritebackCache, CountingDict, LRUCacheDict, DefaultDict
 from .hashable_objects import HashableWrapper
 from .heaps import Heap, SetHeap, TimeBasedHeap, TimeBasedSetHeap
 from .immutable import Immutable, frozendict
 from .mixins import OmniHashableMixin, ReprableMixin, StrEqHashableMixin, ComparableIntEnum, \
-    HashableIntEnum, ComparableAndHashableBy, ComparableAndHashableByInt
+    HashableIntEnum, ComparableAndHashableBy, ComparableAndHashableByInt, ComparableEnum, \
+    HashableMixin
 from .proxy import Proxy
+from .queues import Subqueue
 from .ranking import Ranking
-from .singleton import Singleton, SingletonWithRegardsTo
+from .singleton import Singleton, SingletonWithRegardsTo, get_instances_for_singleton, \
+    delete_singleton_for
 from .sorted_list import SortedList, SliceableDeque
-from .typednamedtuple import typednamedtuple
 from .sparse_matrix import SparseMatrix
+from .typednamedtuple import typednamedtuple
+from .lru import LRU
+from .syncable_droppable import DBStorage, SyncableDroppable
+from .tuples import Vector
+from .push_iterable import PushIterable
 
 __all__ = [
+    'PushIterable',
+    'Vector',
+    'DBStorage', 'SyncableDroppable',
+    'LRU',
+    'LRUCacheDict',
+    'HashableMixin',
+    'CountingDict',
+    'Subqueue',
     'ExclusiveWritebackCache',
+    'DefaultDict',
+    'ComparableEnum',
     'CacheDict',
     'KeyAwareDefaultDict',
     'Proxy',
