@@ -9,11 +9,11 @@ from .structs import create_key, Dict
 
 def _get_descriptor_for_str(key: str, value: str) -> Descriptor:
     try:
-        if value in ('int', 'float', 'str', 'ipv4', 'any', 'bool'):
+        if value in ('int', 'float', 'str', 'ipv4', 'any', 'bool', 'file'):
             return create_key(BASE_LOOKUP_TABLE[value](),
                               key, False, None)
     except KeyError:
-        raise ConfigurationSchemaError('Unknown descriptor type %s' % (value, ))
+        raise ConfigurationSchemaError('Unknown descriptor type %s' % (value,))
 
 
 def _get_descriptor_for_dict(key: str, value: dict) -> Descriptor:
