@@ -1,11 +1,12 @@
+import queue
 import typing as tp
 import warnings
 
 __all__ = ['BaseSatellaError', 'ResourceLockingError', 'ResourceNotLocked', 'ResourceLocked',
            'ConfigurationValidationError', 'ConfigurationError', 'ConfigurationSchemaError',
            'PreconditionError', 'MetricAlreadyExists', 'BaseSatellaException', 'CustomException',
-           'CodedCustomException', 'CodedCustomExceptionMetaclass', 'WouldWaitMore', 'LockIsHeld',
-           'ProcessFailed', 'AlreadyAllocated']
+           'CodedCustomException', 'CodedCustomExceptionMetaclass', 'WouldWaitMore',
+           'ProcessFailed', 'AlreadyAllocated', 'Empty', 'ImpossibleError']
 
 
 class CustomException(Exception):
@@ -25,8 +26,11 @@ class CustomException(Exception):
 
     def __str__(self) -> str:
         a = '%s(%s' % (self.__class__.__qualname__.split('.')[-1], ', '.join(map(repr, self.args)))
-        if self.kwargs:
-            a += ', ' + ', '.join(map(lambda k, v: '%s=%s' % (k, repr(v)), self.kwargs.items()))
+        try:
+            if self.kwargs:
+                a += ', ' + ', '.join(map(lambda k, v: '%s=%s' % (k, repr(v)), self.kwargs.items()))
+        except AttributeError:
+            pass
         a += ')'
         return a
 
@@ -35,9 +39,12 @@ class CustomException(Exception):
                          if self.__class__.__module__ != 'builtins' else '',
                          self.__class__.__qualname__,
                          ', '.join(map(repr, self.args)))
-        if self.kwargs:
-            a += ', ' + (', '.join(map(lambda kv: '%s=%s' % (kv[0], repr(kv[1])),
-                                       self.kwargs.items())))
+        try:
+            if self.kwargs:
+                a += ', ' + (', '.join(map(lambda kv: '%s=%s' % (kv[0], repr(kv[1])),
+                                           self.kwargs.items())))
+        except AttributeError:
+            pass
         a += ')'
         return a
 
@@ -121,7 +128,8 @@ class CodedCustomException(CustomException, metaclass=CodedCustomExceptionMetacl
     >>  a.code = 5
     >>> assert not isinstance(a, MyCode5Diff)
     """
-    def __init__(self, message, code=None, *args, **kwargs):
+
+    def __init__(self, message='', code=None, *args, **kwargs):
         super().__init__(message, code, *args, **kwargs)
         self.message = message  # type: str
         if code is not None:
@@ -161,6 +169,10 @@ class PreconditionError(BaseSatellaError, ValueError):
     """
 
 
+class Empty(BaseSatellaError, queue.Empty):
+    """The queue was empty"""
+
+
 class ConfigurationError(BaseSatellaError, ValueError):
     """A generic error during configuration"""
 
@@ -190,19 +202,6 @@ class MetricAlreadyExists(BaseSatellaError):
         self.existing_type = existing_type
 
 
-class LockIsHeld(ResourceLocked):
-    """
-    An exception raised when lock is held by someone
-
-    :param pid: PID of the holder, who is alive at the time this exception was raised.
-        This is checked via psutil.
-    """
-
-    def __init__(self, pid):
-        super().__init__(pid)
-        self.pid = pid
-
-
 class AlreadyAllocated(ResourceLocked):
     """
     Given ID has been already marked as allocated
@@ -210,7 +209,8 @@ class AlreadyAllocated(ResourceLocked):
 
 
 class ProcessFailed(BaseSatellaError, OSError):
-    """A process finished with other result code that it was requested
+    """
+    A process finished with other result code than it was requested
 
     :param rc: return code of the process
     :param stdout_so_far: process' stdout gathered so far
@@ -223,3 +223,12 @@ class ProcessFailed(BaseSatellaError, OSError):
 
     def __str__(self):
         return 'ProcessFailed(%s)' % (self.rc,)
+
+
+class ImpossibleError(BaseException):
+    """
+    For these cases where your execution flow goes some place, that should be impossible
+    for it to reach.
+
+    This is a BaseException, since it should be propagated upwards as soon as possible!
+    """
